You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@click.apache.org by sa...@apache.org on 2010/07/14 16:31:09 UTC

svn commit: r964060 - /click/trunk/click/framework/src/org/apache/click/ClickServlet.java

Author: sabob
Date: Wed Jul 14 14:31:09 2010
New Revision: 964060

URL: http://svn.apache.org/viewvc?rev=964060&view=rev
Log:
pass page to renderPartial method. Future features could depend on the Page instance.

Modified:
    click/trunk/click/framework/src/org/apache/click/ClickServlet.java

Modified: click/trunk/click/framework/src/org/apache/click/ClickServlet.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/src/org/apache/click/ClickServlet.java?rev=964060&r1=964059&r2=964060&view=diff
==============================================================================
--- click/trunk/click/framework/src/org/apache/click/ClickServlet.java (original)
+++ click/trunk/click/framework/src/org/apache/click/ClickServlet.java Wed Jul 14 14:31:09 2010
@@ -883,7 +883,7 @@ public class ClickServlet extends HttpSe
             }
 
         } else if (partial != null) {
-            renderPartial(partial, context);
+            renderPartial(partial, page, context);
 
         } else if (page.getPath() != null) {
             // Render template unless the request was a page action. This check
@@ -1017,10 +1017,11 @@ public class ClickServlet extends HttpSe
      * Render the given Partial response. If the partial is null, nothing is
      * rendered.
      *
      * @param partial the partial resopnse to render
      * @param context the request context
      */
-    protected void renderPartial(Partial partial, Context context) {
+    protected void renderPartial(Partial partial, Page page, Context context) {
         if (partial == null) {
             return;
         }
@@ -1816,7 +1817,7 @@ public class ClickServlet extends HttpSe
                 controlRegistry.processPreResponse(context);
                 controlRegistry.processPreGetHeadElements(context);
 
-                renderPartial(partial, context);
+                renderPartial(partial, page, context);
             }
         }
 
@@ -1843,7 +1844,7 @@ public class ClickServlet extends HttpSe
                 partial = eventDispatcher.getPartial();
 
                 // Render the partial
-                renderPartial(partial, context);
+                renderPartial(partial, page, context);
 
             } else {
@@ -1017,10 +1017,11 @@ public class ClickServlet extends HttpSe
      * rendered.
      *
-     * @param partial the partial resopnse to render
+     * @param partial the partial response to render
+     * @param page the requested page
      * @param context the request context
      */